@@ -1,11 +1,12 @@
+import logging
 import os
 import sys
-import boto3
-import logging
 import time
+
+import boto3
+from boto3.dynamodb.conditions import Attr, Key
 from lantern_sl.utils.json import json_float_to_decimal
-from lantern_sl.utils.request import http_response, http_error, res_failed
-from boto3.dynamodb.conditions import Key, Attr
+from lantern_sl.utils.request import http_error, http_response, res_failed
 
 log = logging.getLogger(__name__)
 
@@ -37,7 +38,7 @@ def get_dynamo_connection(region_name=None, endpoint_url=None, force_live=False,
         if endpoint_url:
             params["endpoint_url"] = endpoint_url
     if not force_live:
-        if force_local or "pytest" in sys.modules:
+        if force_local:
             usefule_endpoint = os.environ.get("DYNAMODB_LOCAL_URL", endpoint_url)
             if not usefule_endpoint:
                 raise Exception("in local and test, endpoint_url is required or DYNAMODB_LOCAL_URL environment with local url")
